use std::fmt::{self, Display};

/// https://oreillymedia.github.io/Using_SVG/guide/units.html
#[derive(Clone, Copy, PartialEq, Eq, Debug)]
pub enum SVGUnit {
    /// Pixel units, directly equivalent to SVG user units.
    Pixel,
    /// Inches.
    Inch,
    /// Centimeters.
    Centimeter,
    /// Millimeters.
    Millimeter,
    /// Points.
    Point,
    // Picas.
    Pica,
}

impl SVGUnit {
    pub fn to_user_units(&self) -> f64 {
        use SVGUnit::*;
        match self {
            Pixel => 1.0,
            Inch => 96.0,
            Centimeter => 37.795,
            Millimeter => 3.7795,
            Point => 4.0 / 3.0, // 1.3333
            Pica => 16.0,
        }
    }
}

impl Display for SVGUnit {
    fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
        use SVGUnit::*;
        write!(
            f,
            "{}",
            match &self {
                Pixel => "px",
                Inch => "in",
                Centimeter => "cm",
                Millimeter => "mm",
                Point => "pt",
                Pica => "pc",
            }
        )
    }
}
